Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(650)

Unified Diff: src/objects.h

Issue 148883002: Synchronize with r15594. (Closed) Base URL: https://v8.googlecode.com/svn/branches/experimental/a64
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/mips/stub-cache-mips.cc ('k') | src/objects.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index 03a93dd96a19fca15495ebcc314fdd93568fb19f..f4fc560b9795854f2e018a750bc656ae7c53c1b5 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -7467,31 +7467,30 @@ enum AllocationSiteMode {
class AllocationSite: public Struct {
public:
- static const int kPayloadOffset = HeapObject::kHeaderSize;
- static const int kSize = kPayloadOffset + kPointerSize;
+ static const int kTransitionInfoOffset = HeapObject::kHeaderSize;
+ static const int kSize = kTransitionInfoOffset + kPointerSize;
static const uint32_t kMaximumArrayBytesToPretransition = 8 * 1024;
- // TODO(mvstanton): rename payload to transition_info.
- DECL_ACCESSORS(payload, Object)
+ DECL_ACCESSORS(transition_info, Object)
void Initialize() {
- SetElementsKindPayload(GetInitialFastElementsKind());
+ SetElementsKind(GetInitialFastElementsKind());
}
- ElementsKind GetElementsKindPayload() {
+ ElementsKind GetElementsKind() {
ASSERT(!IsLiteralSite());
- return static_cast<ElementsKind>(Smi::cast(payload())->value());
+ return static_cast<ElementsKind>(Smi::cast(transition_info())->value());
}
- void SetElementsKindPayload(ElementsKind kind) {
- set_payload(Smi::FromInt(static_cast<int>(kind)));
+ void SetElementsKind(ElementsKind kind) {
+ set_transition_info(Smi::FromInt(static_cast<int>(kind)));
}
bool IsLiteralSite() {
// If the payload is a smi, then it represents an ElementsKind
// for a constructed array. Otherwise, it must be a boilerplate
// for an array literal
- return payload()->IsJSArray();
+ return transition_info()->IsJSArray();
}
DECLARE_PRINTER(AllocationSite)
« no previous file with comments | « src/mips/stub-cache-mips.cc ('k') | src/objects.cc » ('j') | no next file with comments »
@@ -7467,31 +7467,30 @@ enum AllocationSiteMode {
}
bool IsLiteralSite() {
- // If the payload is a smi, then it represents an ElementsKind
+ // If transition_info is a smi, then it represents an ElementsKind
// for a constructed array. Otherwise, it must be a boilerplate
// for an array literal

Powered by Google App Engine
This is Rietveld 408576698